@@ -1,27 +1,7 @@
-
-# Copyright (C) 2011 Mattias Slabanja <slabanja@chalmers.se>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
-
 __all__ = ['fixed_bin_averager']
 
 import numpy as np
-import logging
-
-logger = logging.getLogger('dynasor')
+from dsf.logging_tools import logger
 
 
 class fixed_bin_averager:
