@@ -1,21 +1,3 @@
-
-# Copyright (C) 2011 Mattias Slabanja <slabanja@chalmers.se>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
-
 """
 This module provides an implementation of Filon's integration formula.
 For information about Filon's formula, see e.g.
@@ -51,7 +33,7 @@ from numpy import (sin, cos, pi, mod, zeros, arange,
 
 
 def fourier_cos(f, dx, k=None, axis=0):
-    """Calculates the direct Fourier cosine transform :math:`F(k)` of a
+    r"""Calculates the direct Fourier cosine transform :math:`F(k)` of a
     function :math:`f(x)` using Filon's integration method.
 
     The array values ``f[0]..f[2n]`` are expected to correspond to
@@ -96,7 +78,7 @@ def fourier_cos(f, dx, k=None, axis=0):
 
 
 def cos_integral(f, dx, k, x0=0.0, axis=0):
-    """Calculates the integral
+    r"""Calculates the integral
     :math:`\int_{x_0}^{2n\Delta x} f(x) \cos(k x) dx`.
 
     Parameters
@@ -123,7 +105,7 @@ def cos_integral(f, dx, k, x0=0.0, axis=0):
 
 
 def sin_integral(f, dx, k, x0=0.0, axis=0):
-    """Calculates the integral
+    r"""Calculates the integral
     :math:`\int_{x_0}^{2n\Delta x} f(x) \sin(k x) dx`.
 
     Parameters
