@@ -1,21 +1,3 @@
-
-# Copyright (C) 2012 Mattias Slabanja <slabanja@chalmers.se>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
-
 import numpy as np
 import re
 
@@ -81,12 +63,12 @@ class section_index:
 
         Split x/v into list of xs/vs in accordance with specified sections.
         """
-        indices = [I for _, I in self.sections]
+        indices = [II for _, II in self.sections]
 
         def fun(frame):
             frame = frame.copy()
-            frame['xs'] = [frame['x'][:, I] for I in indices]
+            frame['xs'] = [frame['x'][:, II] for II in indices]
             if 'v' in frame:
-                frame['vs'] = [frame['v'][:, I] for I in indices]
+                frame['vs'] = [frame['v'][:, II] for II in indices]
             return frame
         return fun
