@@ -2,9 +2,7 @@ __all__ = ['create_mfile', 'create_pfile']
 
 import sys
 import numpy as np
-import logging
-
-logger = logging.getLogger('dynasor')
+from dsf.logging_tools import logger
 
 
 def create_mfile(filename, output, comment=None):
