@@ -1,25 +1,6 @@
-
-# Copyright (C) 2011 Mattias Slabanja <slabanja@chalmers.se>
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful, but
-# WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-# 02110-1301, USA.
-
 __all__ = ['reciprocal_isotropic', 'reciprocal_line']
 
 
-import logging
 import numpy as np
 
 from ctypes import cdll, c_int
@@ -27,7 +8,10 @@ from distutils.sysconfig import get_config_var
 from numpy import linalg, array, arange, require, nonzero, pi, sqrt, prod
 from os.path import dirname, join
 
-logger = logging.getLogger('dynasor')
+from dsf.rho_j_k_numba import rho_k as rho_k_numba
+from dsf.rho_j_k_numba import rho_j_k as rho_j_k_numba
+from dsf.conf import conf
+
 
 np_f = dict(d=np.float64, s=np.float32)
 np_c = dict(d=np.complex128, s=np.complex64)
@@ -71,7 +55,13 @@ def calc_rho_k(x, k, ftype='d'):
     _, Nx = x.shape
     _, Nk = k.shape
     rho_k = np.zeros((Nk,), dtype=np_c[ftype], order='F')
-    _lib[ftype].rho_k(x, Nx, k, Nk, rho_k)
+
+    if conf['backend'] == 'c':
+        _lib[ftype].rho_k(x, Nx, k, Nk, rho_k)
+    elif conf['backend'] == 'numba':
+        x = x.copy()
+        rho_k_numba(x, Nx, k, Nk, rho_k)
+
     return rho_k
 
 
@@ -86,7 +76,12 @@ def calc_rho_j_k(x, v, k, ftype='d'):
     _, Nk = k.shape
     rho_k = np.zeros((Nk,), dtype=np_c[ftype], order='F')
     j_k = np.zeros((3, Nk), dtype=np_c[ftype], order='F')
-    _lib[ftype].rho_j_k(x, v, Nx, k, Nk, rho_k, j_k)
+
+    if conf['backend'] == 'c':
+        _lib[ftype].rho_j_k(x, v, Nx, k, Nk, rho_k, j_k)
+    elif conf['backend'] == 'numba':
+        rho_j_k_numba(x, v, Nx, k, Nk, rho_k, j_k)
+
     return rho_k, j_k
 
 
@@ -168,7 +163,7 @@ class reciprocal_isotropic(reciprocal_processor):
         ftype can be either 'd' or 's' (double or single precission)
         """
 
-        assert(max_points > 1000)
+        assert max_points > 1000
 
         self.max_k = max_k
         self.max_points = max_points
@@ -199,10 +194,10 @@ class reciprocal_isotropic(reciprocal_processor):
         k_points = k_points.reshape((3, int(k_points.size / 3)))
         q_distance = sqrt(np.sum(k_points ** 2, axis=0)) * (1.0 / (2 * pi))
 
-        I, = nonzero(q_distance <= max_q)
-        I = I[q_distance[I].argsort()]
-        q_distance = q_distance[I]
-        k_points = k_points[:, I]  # All k_points < max_k, sorted by length
+        II, = nonzero(q_distance <= max_q)
+        II = II[q_distance[II].argsort()]
+        q_distance = q_distance[II]
+        k_points = k_points[:, II]  # All k_points < max_k, sorted by length
 
         if self.q_prune is not None:
             N = len(q_distance)
@@ -213,9 +208,9 @@ class reciprocal_isotropic(reciprocal_processor):
             p = np.ones(N)
             p[1:] = (self.q_prune / q_distance[1:]) ** 2
 
-            I, = nonzero(p > np.random.rand(N))
-            q_distance = q_distance[I]
-            k_points = k_points[:, I]
+            II, = nonzero(p > np.random.rand(N))
+            q_distance = q_distance[II]
+            k_points = k_points[:, II]
 
         self.k_points = k_points
         self.q_distance = q_distance
